@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: vfeed.pl 3 2014-04-08 11:43:16Z gomor $
+# $Id: vfeed.pl 11 2014-04-10 11:55:50Z gomor $
 #
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ use Data::Dumper;
 use Getopt::Std;
 
 my %opts;
-getopts('f:m:c:', \%opts);
+getopts('d:m:c:', \%opts);
 
 my $method = $opts{m} || 'get_cve';
 my $cve = $opts{c} || 'CVE-2014';
@@ -21,8 +21,8 @@ my $log = vFeed::Log->new;
 my $vfeed = vFeed::DB->new(
    log => $log,
 );
-if (defined($opts{f})) {
-   $vfeed->file($opts{f});
+if (defined($opts{d})) {
+   $vfeed->file($opts{d});
 }
 
 $vfeed->init;
